Usage Reference for :mod:`pyvisfile.vtk`
========================================

.. automodule:: pyvisfile.vtk
.. moduleauthor:: Andreas Kloeckner <inform@tiker.net>


Examples
--------

Writing a structured mesh
^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../examples/vtk-structured-2d-plain.py

(You can find this example as
:download:`examples/vtk-structured-2d-plain.py <../examples/vtk-structured-2d-plain.py>` in the PyVisfile
source distribution.)

Writing an unstructured mesh
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../examples/vtk-unstructured-points.py

(You can find this example as
:download:`examples/vtk-unstructured-points.py <../examples/vtk-unstructured-points.py>` in the PyVisfile
source distribution.)
